@@ -11,17 +11,16 @@
 #include <QDir>
 #include <QFile>
 #include <QFileInfo>
-#include <QFontDatabase>
 #include <QGuiApplication>
 
 #include <KDirWatch>
 #include <KIconLoader>
-#include <KIconTheme>
 #include <KSharedConfig>
 #include <KWindowEffects>
 #include <KWindowSystem>
 #include <KX11Extras>
-#include <kpluginmetadata.h>
+
+#include "libplasma-theme-global.h"
 
 namespace Plasma
 {
@@ -30,9 +29,8 @@ const char ThemePrivate::themeRcFile[] = "plasmarc";
 // the system colors theme is used to cache unthemed svgs with colorization needs
 // these svgs do not follow the theme's colors, but rather the system colors
 const char ThemePrivate::systemColorsTheme[] = "internal-system-colors";
-#if HAVE_X11
-EffectWatcher *ThemePrivate::s_backgroundContrastEffectWatcher = nullptr;
-#endif
+
+ContrastEffectWatcher *ThemePrivate::s_backgroundContrastEffectWatcher = nullptr;
 
 ThemePrivate *ThemePrivate::globalTheme = nullptr;
 QHash<QString, ThemePrivate *> ThemePrivate::themes = QHash<QString, ThemePrivate *>();
@@ -61,17 +59,15 @@ KPluginMetaData metaDataForTheme(const QString &theme)
     }
     if (QFileInfo::exists(packageBasePath + QLatin1String("/metadata.json"))) {
         return KPluginMetaData::fromJsonFile(packageBasePath + QLatin1String("/metadata.json"));
-    } else if (QFileInfo::exists(packageBasePath + QLatin1String("/metadata.desktop"))) {
-        QString metadataPath = packageBasePath + QLatin1String("/metadata.desktop");
-        KConfigGroup cg(KSharedConfig::openConfig(packageBasePath + QLatin1String("/metadata.desktop"), KConfig::SimpleConfig),
-                        QStringLiteral("Desktop Entry"));
+    } else if (QString metadataPath = packageBasePath + QLatin1String("/metadata.desktop"); QFileInfo::exists(metadataPath)) {
+        KConfigGroup cg(KSharedConfig::openConfig(metadataPath, KConfig::SimpleConfig), QStringLiteral("Desktop Entry"));
         QJsonObject obj = {};
         for (const QString &key : cg.keyList()) {
             obj[key] = cg.readEntry(key);
         }
         qWarning(LOG_PLASMA) << "The theme" << theme
                              << "uses the legacy metadata.desktop. Consider contacting the author and asking them update it to use the newer JSON format.";
-        return KPluginMetaData(obj, packageBasePath + QLatin1String("/metadata.desktop"));
+        return KPluginMetaData(obj, metadataPath);
     } else {
         qCWarning(LOG_PLASMA) << "Could not locate metadata for theme" << theme;
         return {};
@@ -114,14 +110,18 @@ ThemePrivate::ThemePrivate(QObject *parent)
     }
 
     ThemeConfig config;
-    cacheTheme = config.cacheTheme();
     kSvgImageSet = std::unique_ptr<KSvg::ImageSet>(new KSvg::ImageSet);
     kSvgImageSet->setBasePath(QStringLiteral(PLASMA_RELATIVE_DATA_INSTALL_DIR "/desktoptheme/"));
 
-    pixmapSaveTimer = new QTimer(this);
-    pixmapSaveTimer->setSingleShot(true);
-    pixmapSaveTimer->setInterval(600);
-    QObject::connect(pixmapSaveTimer, &QTimer::timeout, this, &ThemePrivate::scheduledCacheUpdate);
+    // Event compress updateKSvgSelectors, because when compositing changes,
+    // compositingactive and effect available will both happen in short succession
+    // in a not really deterministic order
+    selectorsUpdateTimer = new QTimer(this);
+    selectorsUpdateTimer->setSingleShot(true);
+    selectorsUpdateTimer->setInterval(600);
+    QObject::connect(selectorsUpdateTimer, &QTimer::timeout, this, [this]() {
+        updateKSvgSelectors(PixmapCache | SvgElementsCache);
+    });
 
     updateNotificationTimer = new QTimer(this);
     updateNotificationTimer->setSingleShot(true);
@@ -129,20 +129,12 @@ ThemePrivate::ThemePrivate(QObject *parent)
     QObject::connect(updateNotificationTimer, &QTimer::timeout, this, &ThemePrivate::notifyOfChanged);
 
     if (QPixmap::defaultDepth() > 8) {
-#if HAVE_X11
         // watch for background contrast effect property changes as well
         if (!s_backgroundContrastEffectWatcher) {
-            s_backgroundContrastEffectWatcher = new EffectWatcher(QStringLiteral("_KDE_NET_WM_BACKGROUND_CONTRAST_REGION"));
+            s_backgroundContrastEffectWatcher = new ContrastEffectWatcher();
         }
 
-        QObject::connect(s_backgroundContrastEffectWatcher, &EffectWatcher::effectChanged, this, [this](bool active) {
-            if (backgroundContrastActive != active) {
-                backgroundContrastActive = active;
-                scheduleThemeChangeNotification(PixmapCache | SvgElementsCache);
-                kSvgImageSet->setSelectors({QStringLiteral("translucent")});
-            }
-        });
-#endif
+        QObject::connect(s_backgroundContrastEffectWatcher, &ContrastEffectWatcher::effectChanged, selectorsUpdateTimer, qOverload<>(&QTimer::start));
     }
     QCoreApplication::instance()->installEventFilter(this);
 
@@ -159,9 +151,9 @@ ThemePrivate::ThemePrivate(QObject *parent)
     });
 
     if (KWindowSystem::isPlatformX11()) {
-        connect(KX11Extras::self(), &KX11Extras::compositingChanged, this, &ThemePrivate::compositingChanged);
-        compositingChanged(KX11Extras::compositingActive());
+        connect(KX11Extras::self(), &KX11Extras::compositingChanged, selectorsUpdateTimer, qOverload<>(&QTimer::start));
     }
+    updateKSvgSelectors(NoCache);
 }
 
 ThemePrivate::~ThemePrivate()
@@ -189,113 +181,6 @@ KConfigGroup &ThemePrivate::config()
     return cfg;
 }
 
-bool ThemePrivate::useCache()
-{
-    bool cachesTooOld = false;
-
-    if (cacheTheme) {
-        if (cacheSize == 0) {
-            ThemeConfig config;
-            cacheSize = config.themeCacheKb();
-        }
-        const bool isRegularTheme = themeName != QLatin1String(systemColorsTheme);
-        QString cacheFile = QLatin1String("plasma_theme_") + themeName;
-
-        // clear any cached values from the previous theme cache
-        themeVersion.clear();
-
-        if (!themeMetadataPath.isEmpty()) {
-            KDirWatch::self()->removeFile(themeMetadataPath);
-        }
-        themeMetadataPath = configForTheme(themeName)->name();
-        if (isRegularTheme) {
-            const auto *iconTheme = KIconLoader::global()->theme();
-            if (iconTheme) {
-                iconThemeMetadataPath = iconTheme->dir() + QStringLiteral("index.theme");
-            }
-
-            const QString cacheFileBase = cacheFile + QLatin1String("*.kcache");
-
-            QString currentCacheFileName;
-            if (!themeMetadataPath.isEmpty()) {
-                // now we record the theme version, if we can
-                const KPluginMetaData data = metaDataForTheme(themeName);
-                if (data.isValid()) {
-                    themeVersion = data.version();
-                }
-                if (!themeVersion.isEmpty()) {
-                    cacheFile += QLatin1String("_v") + themeVersion;
-                    currentCacheFileName = cacheFile + QLatin1String(".kcache");
-                }
-
-                // watch the metadata file for changes at runtime
-                KDirWatch::self()->addFile(themeMetadataPath);
-                QObject::connect(KDirWatch::self(), &KDirWatch::created, this, &ThemePrivate::settingsFileChanged, Qt::UniqueConnection);
-                QObject::connect(KDirWatch::self(), &KDirWatch::dirty, this, &ThemePrivate::settingsFileChanged, Qt::UniqueConnection);
-
-                if (!iconThemeMetadataPath.isEmpty()) {
-                    KDirWatch::self()->addFile(iconThemeMetadataPath);
-                }
-            }
-
-            // now we check for, and remove if necessary, old caches
-            QDir cacheDir(QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation));
-            cacheDir.setNameFilters(QStringList({cacheFileBase}));
-
-            const auto files = cacheDir.entryInfoList();
-            for (const QFileInfo &file : files) {
-                if (currentCacheFileName.isEmpty() //
-                    || !file.absoluteFilePath().endsWith(currentCacheFileName)) {
-                    QFile::remove(file.absoluteFilePath());
-                }
-            }
-        }
-
-        // now we do a sanity check: if the metadata.desktop file is newer than the cache, drop the cache
-        if (isRegularTheme && !themeMetadataPath.isEmpty()) {
-            // now we check to see if the theme metadata file itself is newer than the pixmap cache
-            // this is done before creating the pixmapCache object since that can change the mtime
-            // on the cache file
-
-            // FIXME: when using the system colors, if they change while the application is not running
-            // the cache should be dropped; we need a way to detect system color change when the
-            // application is not running.
-            // check for expired cache
-            const QString cacheFilePath =
-                QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + QLatin1Char('/') + cacheFile + QLatin1String(".kcache");
-            if (!cacheFilePath.isEmpty()) {
-                const QFileInfo cacheFileInfo(cacheFilePath);
-                const QFileInfo metadataFileInfo(themeMetadataPath);
-                const QFileInfo iconThemeMetadataFileInfo(iconThemeMetadataPath);
-
-                cachesTooOld = (cacheFileInfo.lastModified().toSecsSinceEpoch() < metadataFileInfo.lastModified().toSecsSinceEpoch())
-                    || (cacheFileInfo.lastModified().toSecsSinceEpoch() < iconThemeMetadataFileInfo.lastModified().toSecsSinceEpoch());
-            }
-        }
-
-        ThemeConfig config;
-
-        if (cachesTooOld) {
-            discardCache(PixmapCache | SvgElementsCache);
-        }
-    }
-
-    if (cacheTheme) {
-        QString currentIconThemePath;
-        const auto *iconTheme = KIconLoader::global()->theme();
-        if (iconTheme) {
-            currentIconThemePath = iconTheme->dir();
-        }
-    }
-
-    return cacheTheme;
-}
-
-void ThemePrivate::onAppExitCleanup()
-{
-    cacheTheme = false;
-}
-
 QString ThemePrivate::imagePath(const QString &theme, const QString &type, const QString &image)
 {
     QString subdir = QLatin1String(PLASMA_RELATIVE_DATA_INSTALL_DIR "/desktoptheme/") % theme % type % image;
@@ -332,20 +217,32 @@ QString ThemePrivate::findInTheme(const QString &image, const QString &theme, bo
     return search;
 }
 
-void ThemePrivate::compositingChanged(bool active)
+void ThemePrivate::updateKSvgSelectors(CacheTypes notify)
 {
 #if HAVE_X11
-    if (compositingActive != active) {
-        compositingActive = active;
-        // qCDebug(LOG_PLASMA) << QTime::currentTime();
-        scheduleThemeChangeNotification(PixmapCache | SvgElementsCache);
-        if (active) {
-            kSvgImageSet->setSelectors({});
-        } else {
-            kSvgImageSet->setSelectors({QStringLiteral("opaque")});
-        }
+    if (KWindowSystem::isPlatformX11()) {
+        compositingActive = KX11Extras::compositingActive();
+    } else {
+        compositingActive = true;
     }
+#else
+    compositingActive = true;
 #endif
+    backgroundContrastActive = s_backgroundContrastEffectWatcher->isEffectActive();
+
+    if (compositingActive) {
+        if (backgroundContrastActive) {
+            kSvgImageSet->setSelectors({QStringLiteral("translucent")});
+        } else {
+            kSvgImageSet->setSelectors({});
+        }
+    } else {
+        kSvgImageSet->setSelectors({QStringLiteral("opaque")});
+    }
+
+    if (notify != NoCache) {
+        scheduleThemeChangeNotification(notify);
+    }
 }
 
 void ThemePrivate::discardCache(CacheTypes caches)
@@ -355,10 +252,6 @@ void ThemePrivate::discardCache(CacheTypes caches)
     }
 }
 
-void ThemePrivate::scheduledCacheUpdate()
-{
-}
-
 void ThemePrivate::colorsChanged()
 {
     // in the case the theme follows the desktop settings, refetch the colorschemes
@@ -655,7 +548,7 @@ void ThemePrivate::setThemeName(const QString &tempThemeName, bool writeSettings
 
         // Check for what Plasma version the theme has been done
         // There are some behavioral differences between KDE4 Plasma and Plasma 5
-        const QString apiVersion = pluginMetaData.value(QStringLiteral("X-Plasma-API"));
+        const QString apiVersion = pluginMetaData.value(u"X-Plasma-API");
         apiMajor = 1;
         apiMinor = 0;
         apiRevision = 0;
