@@ -52,10 +52,10 @@ AppletQuickItemPrivate::AppletQuickItemPrivate(AppletQuickItem *item)
         s_preloadPolicy = Adaptive;
 
         if (qEnvironmentVariableIsSet("PLASMA_PRELOAD_POLICY")) {
-            const QString policy = QString::fromUtf8(qgetenv("PLASMA_PRELOAD_POLICY")).toLower();
-            if (policy == QLatin1String("aggressive")) {
+            const QString policy = qEnvironmentVariable("PLASMA_PRELOAD_POLICY");
+            if (policy.compare(QLatin1String("aggressive"), Qt::CaseInsensitive) == 0) {
                 s_preloadPolicy = Aggressive;
-            } else if (policy == QLatin1String("none")) {
+            } else if (policy.compare(QLatin1String("none"), Qt::CaseInsensitive) == 0) {
                 s_preloadPolicy = None;
             }
         }
@@ -67,7 +67,7 @@ AppletQuickItemPrivate::AppletQuickItemPrivate(AppletQuickItem *item)
 int AppletQuickItemPrivate::preloadWeight() const
 {
     int defaultWeight;
-    const QStringList provides = applet->pluginMetaData().value(QStringLiteral("X-Plasma-Provides"), QStringList());
+    const QStringList provides = applet->pluginMetaData().value(u"X-Plasma-Provides", QStringList());
 
     // some applet types we want a bigger weight
     if (provides.contains(QLatin1String("org.kde.plasma.launchermenu"))) {
@@ -76,10 +76,10 @@ int AppletQuickItemPrivate::preloadWeight() const
         defaultWeight = DefaultPreloadWeight;
     }
     // default widgets to be barely preloaded
-    return qBound(0,
-                  applet->config().readEntry(QStringLiteral("PreloadWeight"),
-                                             qMax(defaultWeight, applet->pluginMetaData().value(QStringLiteral("X-Plasma-PreloadWeight"), 0))),
-                  100);
+    return qBound(
+        0,
+        applet->config().readEntry(QStringLiteral("PreloadWeight"), qMax(defaultWeight, applet->pluginMetaData().value(u"X-Plasma-PreloadWeight", 0))),
+        100);
 }
 
 QObject *AppletQuickItemPrivate::searchLayoutAttached(QObject *parent) const
@@ -561,7 +561,7 @@ AppletQuickItem *AppletQuickItem::itemForApplet(Plasma::Applet *applet)
         errorData[QStringLiteral("isDebugMode")] = qEnvironmentVariableIntValue("PLASMA_ENABLE_QML_DEBUG") != 0;
 
         if (applet->sourceValid()) {
-            const QString versionString = applet->pluginMetaData().value(QStringLiteral("X-Plasma-API-Minimum-Version"));
+            const QString versionString = applet->pluginMetaData().value(u"X-Plasma-API-Minimum-Version");
             QVersionNumber version;
             if (!versionString.isEmpty()) {
                 version = QVersionNumber::fromString(versionString);
@@ -922,6 +922,21 @@ void AppletQuickItem::setPreloadFullRepresentation(bool preload)
     Q_EMIT preloadFullRepresentationChanged(preload);
 }
 
+bool AppletQuickItem::expandedOnDragHover() const
+{
+    return d->expandedOnDragHover;
+}
+
+void AppletQuickItem::setExpandedOnDragHover(bool expandedOnDragHover)
+{
+    if (expandedOnDragHover == d->expandedOnDragHover) {
+        return;
+    }
+
+    d->expandedOnDragHover = expandedOnDragHover;
+    Q_EMIT expandedOnDragHoverChanged(expandedOnDragHover);
+}
+
 ////////////Internals
 
 PlasmaQuick::SharedQmlEngine *AppletQuickItem::qmlObject()
